---
title: Winter Animals
id: winter-animals
layout: default.haml
author: Henry David Thoreau
date: 2018-04-15
chapter: 15
category: animals
kind: article
---

## Winter Animals

When the ponds were firmly frozen, they afforded not only new and
shorter routes to many points, but new views from their surfaces of the
familiar landscape around them. When I crossed Flint’s Pond, after it
was covered with snow, though I had often paddled about and skated over
it, it was so unexpectedly wide and so strange that I could think of
nothing but Baffin’s Bay. The Lincoln hills rose up around me at the
extremity of a snowy plain, in which I did not remember to have stood
before; and the fishermen, at an indeterminable distance over the ice,
moving slowly about with their wolfish dogs, passed for sealers or
Esquimaux, or in misty weather loomed like fabulous creatures, and I
did not know whether they were giants or pygmies. I took this course
when I went to lecture in Lincoln in the evening, travelling in no road
and passing no house between my own hut and the lecture room. In Goose
Pond, which lay in my way, a colony of muskrats dwelt, and raised their
cabins high above the ice, though none could be seen abroad when I
crossed it. Walden, being like the rest usually bare of snow, or with
only shallow and interrupted drifts on it, was my yard, where I could
walk freely when the snow was nearly two feet deep on a level elsewhere
and the villagers were confined to their streets. There, far from the
village street, and except at very long intervals, from the jingle of
sleigh-bells, I slid and skated, as in a vast moose-yard well trodden,
overhung by oak woods and solemn pines bent down with snow or bristling
with icicles.

For sounds in winter nights, and often in winter days, I heard the
forlorn but melodious note of a hooting owl indefinitely far; such a
sound as the frozen earth would yield if struck with a suitable
plectrum, the very _lingua vernacula_ of Walden Wood, and quite
familiar to me at last, though I never saw the bird while it was making
it. I seldom opened my door in a winter evening without hearing it;
_Hoo hoo hoo, hoorer, hoo,_ sounded sonorously, and the first three
syllables accented somewhat like _how der do_; or sometimes _hoo hoo_
only. One night in the beginning of winter, before the pond froze over,
about nine o’clock, I was startled by the loud honking of a goose, and,
stepping to the door, heard the sound of their wings like a tempest in
the woods as they flew low over my house. They passed over the pond
toward Fair Haven, seemingly deterred from settling by my light, their
commodore honking all the while with a regular beat. Suddenly an
unmistakable cat-owl from very near me, with the most harsh and
tremendous voice I ever heard from any inhabitant of the woods,
responded at regular intervals to the goose, as if determined to expose
and disgrace this intruder from Hudson’s Bay by exhibiting a greater
compass and volume of voice in a native, and _boo-hoo_ him out of
Concord horizon. What do you mean by alarming the citadel at this time
of night consecrated to me? Do you think I am ever caught napping at
such an hour, and that I have not got lungs and a larynx as well as
yourself? _Boo-hoo, boo-hoo, boo-hoo!_ It was one of the most thrilling
discords I ever heard. And yet, if you had a discriminating ear, there
were in it the elements of a concord such as these plains never saw nor
heard.

I also heard the whooping of the ice in the pond, my great bed-fellow
in that part of Concord, as if it were restless in its bed and would
fain turn over, were troubled with flatulency and had dreams; or I was
waked by the cracking of the ground by the frost, as if some one had
driven a team against my door, and in the morning would find a crack in
the earth a quarter of a mile long and a third of an inch wide.

Sometimes I heard the foxes as they ranged over the snow crust, in
moonlight nights, in search of a partridge or other game, barking
raggedly and demoniacally like forest dogs, as if laboring with some
anxiety, or seeking expression, struggling for light and to be dogs
outright and run freely in the streets; for if we take the ages into
our account, may there not be a civilization going on among brutes as
well as men? They seemed to me to be rudimental, burrowing men, still
standing on their defence, awaiting their transformation. Sometimes one
came near to my window, attracted by my light, barked a vulpine curse
at me, and then retreated.

Usually the red squirrel (_Sciurus Hudsonius_) waked me in the dawn,
coursing over the roof and up and down the sides of the house, as if
sent out of the woods for this purpose. In the course of the winter I
threw out half a bushel of ears of sweet-corn, which had not got ripe,
on to the snow crust by my door, and was amused by watching the motions
of the various animals which were baited by it. In the twilight and the
night the rabbits came regularly and made a hearty meal. All day long
the red squirrels came and went, and afforded me much entertainment by
their manœuvres. One would approach at first warily through the
shrub-oaks, running over the snow crust by fits and starts like a leaf
blown by the wind, now a few paces this way, with wonderful speed and
waste of energy, making inconceivable haste with his “trotters,” as if
it were for a wager, and now as many paces that way, but never getting
on more than half a rod at a time; and then suddenly pausing with a
ludicrous expression and a gratuitous somerset, as if all the eyes in
the universe were fixed on him,—for all the motions of a squirrel, even
in the most solitary recesses of the forest, imply spectators as much
as those of a dancing girl,—wasting more time in delay and
circumspection than would have sufficed to walk the whole distance,—I
never saw one walk,—and then suddenly, before you could say Jack
Robinson, he would be in the top of a young pitch-pine, winding up his
clock and chiding all imaginary spectators, soliloquizing and talking
to all the universe at the same time,—for no reason that I could ever
detect, or he himself was aware of, I suspect. At length he would reach
the corn, and selecting a suitable ear, frisk about in the same
uncertain trigonometrical way to the top-most stick of my wood-pile,
before my window, where he looked me in the face, and there sit for
hours, supplying himself with a new ear from time to time, nibbling at
first voraciously and throwing the half-naked cobs about; till at
length he grew more dainty still and played with his food, tasting only
the inside of the kernel, and the ear, which was held balanced over the
stick by one paw, slipped from his careless grasp and fell to the
ground, when he would look over at it with a ludicrous expression of
uncertainty, as if suspecting that it had life, with a mind not made up
whether to get it again, or a new one, or be off; now thinking of corn,
then listening to hear what was in the wind. So the little impudent
fellow would waste many an ear in a forenoon; till at last, seizing
some longer and plumper one, considerably bigger than himself, and
skilfully balancing it, he would set out with it to the woods, like a
tiger with a buffalo, by the same zig-zag course and frequent pauses,
scratching along with it as if it were too heavy for him and falling
all the while, making its fall a diagonal between a perpendicular and
horizontal, being determined to put it through at any rate;—a
singularly frivolous and whimsical fellow;—and so he would get off with
it to where he lived, perhaps carry it to the top of a pine tree forty
or fifty rods distant, and I would afterwards find the cobs strewn
about the woods in various directions.

At length the jays arrive, whose discordant screams were heard long
before, as they were warily making their approach an eighth of a mile
off, and in a stealthy and sneaking manner they flit from tree to tree,
nearer and nearer, and pick up the kernels which the squirrels have
dropped. Then, sitting on a pitch-pine bough, they attempt to swallow
in their haste a kernel which is too big for their throats and chokes
them; and after great labor they disgorge it, and spend an hour in the
endeavor to crack it by repeated blows with their bills. They were
manifestly thieves, and I had not much respect for them; but the
squirrels, though at first shy, went to work as if they were taking
what was their own.

Meanwhile also came the chickadees in flocks, which, picking up the
crumbs the squirrels had dropped, flew to the nearest twig, and,
placing them under their claws, hammered away at them with their little
bills, as if it were an insect in the bark, till they were sufficiently
reduced for their slender throats. A little flock of these tit-mice
came daily to pick a dinner out of my wood-pile, or the crumbs at my
door, with faint flitting lisping notes, like the tinkling of icicles
in the grass, or else with sprightly _day day day_, or more rarely, in
spring-like days, a wiry summery _phe-be_ from the wood-side. They were
so familiar that at length one alighted on an armful of wood which I
was carrying in, and pecked at the sticks without fear. I once had a
sparrow alight upon my shoulder for a moment while I was hoeing in a
village garden, and I felt that I was more distinguished by that
circumstance than I should have been by any epaulet I could have worn.
The squirrels also grew at last to be quite familiar, and occasionally
stepped upon my shoe, when that was the nearest way.

When the ground was not yet quite covered, and again near the end of
winter, when the snow was melted on my south hill-side and about my
wood-pile, the partridges came out of the woods morning and evening to
feed there. Whichever side you walk in the woods the partridge bursts
away on whirring wings, jarring the snow from the dry leaves and twigs
on high, which comes sifting down in the sun-beams like golden dust;
for this brave bird is not to be scared by winter. It is frequently
covered up by drifts, and, it is said, “sometimes plunges from on wing
into the soft snow, where it remains concealed for a day or two.” I
used to start them in the open land also, where they had come out of
the woods at sunset to “bud” the wild apple-trees. They will come
regularly every evening to particular trees, where the cunning
sportsman lies in wait for them, and the distant orchards next the
woods suffer thus not a little. I am glad that the partridge gets fed,
at any rate. It is Nature’s own bird which lives on buds and
diet-drink.

In dark winter mornings, or in short winter afternoons, I sometimes
heard a pack of hounds threading all the woods with hounding cry and
yelp, unable to resist the instinct of the chase, and the note of the
hunting horn at intervals, proving that man was in the rear. The woods
ring again, and yet no fox bursts forth on to the open level of the
pond, nor following pack pursuing their Actæon. And perhaps at evening
I see the hunters returning with a single brush trailing from their
sleigh for a trophy, seeking their inn. They tell me that if the fox
would remain in the bosom of the frozen earth he would be safe, or if
he would run in a straight line away no fox-hound could overtake him;
but, having left his pursuers far behind, he stops to rest and listen
till they come up, and when he runs he circles round to his old haunts,
where the hunters await him. Sometimes, however, he will run upon a
wall many rods, and then leap off far to one side, and he appears to
know that water will not retain his scent. A hunter told me that he
once saw a fox pursued by hounds burst out on to Walden when the ice
was covered with shallow puddles, run part way across, and then return
to the same shore. Ere long the hounds arrived, but here they lost the
scent. Sometimes a pack hunting by themselves would pass my door, and
circle round my house, and yelp and hound without regarding me, as if
afflicted by a species of madness, so that nothing could divert them
from the pursuit. Thus they circle until they fall upon the recent
trail of a fox, for a wise hound will forsake every thing else for
this. One day a man came to my hut from Lexington to inquire after his
hound that made a large track, and had been hunting for a week by
himself. But I fear that he was not the wiser for all I told him, for
every time I attempted to answer his questions he interrupted me by
asking, “What do you do here?” He had lost a dog, but found a man.

One old hunter who has a dry tongue, who used to come to bathe in
Walden once every year when the water was warmest, and at such times
looked in upon me, told me that many years ago he took his gun one
afternoon and went out for a cruise in Walden Wood; and as he walked
the Wayland road he heard the cry of hounds approaching, and ere long a
fox leaped the wall into the road, and as quick as thought leaped the
other wall out of the road, and his swift bullet had not touched him.
Some way behind came an old hound and her three pups in full pursuit,
hunting on their own account, and disappeared again in the woods. Late
in the afternoon, as he was resting in the thick woods south of Walden,
he heard the voice of the hounds far over toward Fair Haven still
pursuing the fox; and on they came, their hounding cry which made all
the woods ring sounding nearer and nearer, now from Well-Meadow, now
from the Baker Farm. For a long time he stood still and listened to
their music, so sweet to a hunter’s ear, when suddenly the fox
appeared, threading the solemn aisles with an easy coursing pace, whose
sound was concealed by a sympathetic rustle of the leaves, swift and
still, keeping the ground, leaving his pursuers far behind; and,
leaping upon a rock amid the woods, he sat erect and listening, with
his back to the hunter. For a moment compassion restrained the latter’s
arm; but that was a short-lived mood, and as quick as thought can
follow thought his piece was levelled, and _whang!_—the fox rolling
over the rock lay dead on the ground. The hunter still kept his place
and listened to the hounds. Still on they came, and now the near woods
resounded through all their aisles with their demoniac cry. At length
the old hound burst into view with muzzle to the ground, and snapping
the air as if possessed, and ran directly to the rock; but spying the
dead fox she suddenly ceased her hounding as if struck dumb with
amazement, and walked round and round him in silence; and one by one
her pups arrived, and, like their mother, were sobered into silence by
the mystery. Then the hunter came forward and stood in their midst, and
the mystery was solved. They waited in silence while he skinned the
fox, then followed the brush a while, and at length turned off into the
woods again. That evening a Weston Squire came to the Concord hunter’s
cottage to inquire for his hounds, and told how for a week they had
been hunting on their own account from Weston woods. The Concord hunter
told him what he knew and offered him the skin; but the other declined
it and departed. He did not find his hounds that night, but the next
day learned that they had crossed the river and put up at a farm-house
for the night, whence, having been well fed, they took their departure
early in the morning.

The hunter who told me this could remember one Sam Nutting, who used to
hunt bears on Fair Haven Ledges, and exchange their skins for rum in
Concord village; who told him, even, that he had seen a moose there.
Nutting had a famous fox-hound named Burgoyne,—he pronounced it
Bugine,—which my informant used to borrow. In the “Wast Book” of an old
trader of this town, who was also a captain, town-clerk, and
representative, I find the following entry. Jan. 18th, 1742–3, “John
Melven Cr. by 1 Grey Fox 0—2—3;” they are not now found here; and in
his ledger, Feb. 7th, 1743, Hezekiah Stratton has credit “by ½ a Catt
skin 0—1—4½;” of course, a wild-cat, for Stratton was a sergeant in the
old French war, and would not have got credit for hunting less noble
game. Credit is given for deer skins also, and they were daily sold.
One man still preserves the horns of the last deer that was killed in
this vicinity, and another has told me the particulars of the hunt in
which his uncle was engaged. The hunters were formerly a numerous and
merry crew here. I remember well one gaunt Nimrod who would catch up a
leaf by the road-side and play a strain on it wilder and more
melodious, if my memory serves me, than any hunting-horn.

At midnight, when there was a moon, I sometimes met with hounds in my
path prowling about the woods, which would skulk out of my way, as if
afraid, and stand silent amid the bushes till I had passed.

Squirrels and wild mice disputed for my store of nuts. There were
scores of pitch-pines around my house, from one to four inches in
diameter, which had been gnawed by mice the previous winter,—a
Norwegian winter for them, for the snow lay long and deep, and they
were obliged to mix a large proportion of pine bark with their other
diet. These trees were alive and apparently flourishing at mid-summer,
and many of them had grown a foot, though completely girdled; but after
another winter such were without exception dead. It is remarkable that
a single mouse should thus be allowed a whole pine tree for its dinner,
gnawing round instead of up and down it; but perhaps it is necessary in
order to thin these trees, which are wont to grow up densely.

The hares (_Lepus Americanus_) were very familiar. One had her form
under my house all winter, separated from me only by the flooring, and
she startled me each morning by her hasty departure when I began to
stir,—thump, thump, thump, striking her head against the floor timbers
in her hurry. They used to come round my door at dusk to nibble the
potato parings which I had thrown out, and were so nearly the color of
the ground that they could hardly be distinguished when still.
Sometimes in the twilight I alternately lost and recovered sight of one
sitting motionless under my window. When I opened my door in the
evening, off they would go with a squeak and a bounce. Near at hand
they only excited my pity. One evening one sat by my door two paces
from me, at first trembling with fear, yet unwilling to move; a poor
wee thing, lean and bony, with ragged ears and sharp nose, scant tail
and slender paws. It looked as if Nature no longer contained the breed
of nobler bloods, but stood on her last toes. Its large eyes appeared
young and unhealthy, almost dropsical. I took a step, and lo, away it
scud with an elastic spring over the snow crust, straightening its body
and its limbs into graceful length, and soon put the forest between me
and itself,—the wild free venison, asserting its vigor and the dignity
of Nature. Not without reason was its slenderness. Such then was its
nature. (_Lepus_, _levipes_, light-foot, some think.)

What is a country without rabbits and partridges? They are among the
most simple and indigenous animal products; ancient and venerable
families known to antiquity as to modern times; of the very hue and
substance of Nature, nearest allied to leaves and to the ground,—and to
one another; it is either winged or it is legged. It is hardly as if
you had seen a wild creature when a rabbit or a partridge bursts away,
only a natural one, as much to be expected as rustling leaves. The
partridge and the rabbit are still sure to thrive, like true natives of
the soil, whatever revolutions occur. If the forest is cut off, the
sprouts and bushes which spring up afford them concealment, and they
become more numerous than ever. That must be a poor country indeed that
does not support a hare. Our woods teem with them both, and around
every swamp may be seen the partridge or rabbit walk, beset with twiggy
fences and horse-hair snares, which some cow-boy tends.


